@@ -1,5 +1,5 @@
-# -*- coding: utf-8 -*-
 # Copyright 2013 Christoph Reiter
+#           2020 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -7,6 +7,8 @@
 # (at your option) any later version.
 
 import re
+from typing import Tuple, Text
+from quodlibet.browsers.paned.util import PaneConfig
 
 from quodlibet import _
 from quodlibet import util
@@ -17,7 +19,7 @@ from quodlibet.util.collection import Collection
 class BaseEntry(Collection):
 
     def __init__(self, key=None, songs=None):
-        super(BaseEntry, self).__init__()
+        super().__init__()
 
         self.songs = set(songs or [])
         self.key = key # not used for sorting!
@@ -53,14 +55,14 @@ class BaseEntry(Collection):
 class SongsEntry(BaseEntry):
 
     def __init__(self, key, sort, songs=None):
-        super(SongsEntry, self).__init__(key, songs)
+        super().__init__(key, songs)
 
         self.sort = sort # value used for sorting
 
     def get_count_text(self, config):
         return config.format_display(self)
 
-    def get_text(self, config):
+    def get_text(self, config: PaneConfig) -> Tuple[bool, Text]:
         if config.has_markup:
             return True, self.key
         else:
@@ -80,7 +82,7 @@ class SongsEntry(BaseEntry):
 class UnknownEntry(SongsEntry):
 
     def __init__(self, songs=None):
-        super(UnknownEntry, self).__init__("", tuple(), songs)
+        super().__init__("", tuple(), songs)
 
     def get_text(self, config):
         return True, "<b>%s</b>" % _("Unknown")
@@ -95,7 +97,7 @@ class UnknownEntry(SongsEntry):
 class AllEntry(BaseEntry):
 
     def __init__(self):
-        super(AllEntry, self).__init__()
+        super().__init__()
 
     def get_count_text(self, config):
         return u""
@@ -116,7 +118,7 @@ class AllEntry(BaseEntry):
 class PaneModel(ObjectStore):
 
     def __init__(self, pattern_config):
-        super(PaneModel, self).__init__()
+        super().__init__()
         self.__sort_cache = {} # text to sort text cache
         self.__key_cache = {} # song to key cache
         self.config = pattern_config
