@@ -1,5 +1,5 @@
 # Copyright 2005 Joe Wreschnig
-#    2012 - 2018 Nick Boultbee
+#    2012 - 2020 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@ from quodlibet.plugins.playlist import PLAYLIST_HANDLER
 from quodlibet.qltk.completion import LibraryTagCompletion
 from quodlibet.qltk.menubutton import MenuButton
 from quodlibet.qltk.models import ObjectStore, ObjectModelSort
+from quodlibet.qltk.msg import ConfirmationPrompt
 from quodlibet.qltk.searchbar import SearchBarBox
 from quodlibet.qltk.songlist import SongList
 from quodlibet.qltk.songsmenu import SongsMenu
@@ -34,11 +35,11 @@ from quodlibet.qltk.information import Information
 from quodlibet.qltk.properties import SongProperties
 from quodlibet.util import connect_obj
 from quodlibet.util.dprint import print_d, print_w
-from quodlibet.util.collection import FileBackedPlaylist
+from quodlibet.util.collection import XSPFBackedPlaylist, FileBackedPlaylist
 from quodlibet.util.urllib import urlopen
 
 from .util import parse_m3u, parse_pls, PLAYLISTS,\
-    ConfirmRemovePlaylistDialog, _name_for
+    confirm_remove_playlist_dialog_invoke, _name_for
 
 DND_QL, DND_URI_LIST, DND_MOZ_URL = range(3)
 
@@ -75,13 +76,18 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
         klass.library = library
         model = klass.__lists.get_model()
         for playlist in os.listdir(PLAYLISTS):
+            if os.path.isdir(os.path.join(PLAYLISTS, playlist)):
+                continue
             try:
-                playlist = FileBackedPlaylist(PLAYLISTS,
-                      FileBackedPlaylist.unquote(playlist), library=library)
+                playlist = XSPFBackedPlaylist(PLAYLISTS, playlist, library)
+                model.append(row=[playlist])
+            except TypeError:
+                legacy = FileBackedPlaylist(PLAYLISTS, playlist, library)
+                print_w("Converting \"%s\" to XSPF format" % playlist)
+                playlist = XSPFBackedPlaylist.from_playlist(legacy, library)
                 model.append(row=[playlist])
             except EnvironmentError:
                 print_w("Invalid Playlist '%s'" % playlist)
-                pass
 
         klass._ids = [
             library.connect('removed', klass.__removed),
@@ -119,6 +125,8 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
 
     @classmethod
     def __removed(klass, library, songs):
+        print_d(f"Removing {len(songs)} song(s) "
+                f"across {len(klass.playlists())} playlist(s)")
         for playlist in klass.playlists():
             if playlist.remove_songs(songs):
                 klass.changed(playlist)
@@ -135,6 +143,7 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
         for playlist in klass.playlists():
             for song in songs:
                 if song in playlist.songs:
+                    print_d(f"Playlist song {song.key!r} changed, so updating")
                     klass.changed(playlist)
                     break
 
@@ -155,7 +164,7 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
         playlist_iter = self.__selected_playlists()[1]
         remove.set_sensitive(bool(playlist_iter))
         items.append([remove])
-        menu = super(PlaylistsBrowser, self).Menu(songs, library, items)
+        menu = super().Menu(songs, library, items)
         return menu
 
     def __get_selected_songs(self):
@@ -167,9 +176,12 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
     __lists = ObjectModelSort(model=ObjectStore())
     __lists.set_default_sort_func(ObjectStore._sort_on_value)
 
-    def __init__(self, library):
+    def __init__(self, library, Confirmer=ConfirmationPrompt):
         self.library = library
-        super(PlaylistsBrowser, self).__init__(spacing=6)
+        # this is instanced with the necessary gtkdialog-settings, and afterwards
+        # its run-method is called to get a to-be-compared Gtk.ResponseType
+        self.Confirmer = Confirmer
+        super().__init__(spacing=6)
         self.set_orientation(Gtk.Orientation.VERTICAL)
         self.__render = self.__create_cell_renderer()
         self.__view = view = self.__create_playlists_view(self.__render)
@@ -300,11 +312,14 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
                 return False
 
             playlist = model[iter][0]
-            dialog = ConfirmRemovePlaylistDialog(self, playlist)
-            if dialog.run() == Gtk.ResponseType.YES:
+            response = confirm_remove_playlist_dialog_invoke(
+                self, playlist, self.Confirmer)
+            if response:
                 playlist.delete()
                 model.get_model().remove(
                     model.convert_iter_to_child_iter(iter))
+            else:
+                print_d("Playlist removal cancelled through prompt")
             return True
         elif qltk.is_accel(event, "F2"):
             model, iter = self.__selected_playlists()
@@ -399,7 +414,7 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
             try:
                 path, pos = view.get_dest_row_at_pos(x, y)
             except TypeError:
-                playlist = FileBackedPlaylist.from_songs(PLAYLISTS, songs,
+                playlist = XSPFBackedPlaylist.from_songs(PLAYLISTS, songs,
                                                          library)
                 GLib.idle_add(self._select_playlist, playlist)
             else:
@@ -478,12 +493,14 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
 
         def _remove(model, itr):
             playlist = model[itr][0]
-            dialog = ConfirmRemovePlaylistDialog(self, playlist)
-            if dialog.run() == Gtk.ResponseType.YES:
+            response = confirm_remove_playlist_dialog_invoke(
+                self, playlist, self.Confirmer)
+            if response:
                 playlist.delete()
                 model.get_model().remove(
                     model.convert_iter_to_child_iter(itr))
-
+            else:
+                print_d("Playlist removal cancelled through prompt")
         rem = MenuItem(_("_Delete"), Icons.EDIT_DELETE)
         connect_obj(rem, 'activate', _remove, model, itr)
         menu.prepend(rem)
@@ -549,7 +566,7 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
 
     def can_filter(self, key):
         # TODO: special-case the ~playlists tag maybe?
-        return super(PlaylistsBrowser, self).can_filter(key)
+        return super().can_filter(key)
 
     def finalize(self, restore):
         config.set("browsers", "query_text", "")
@@ -569,7 +586,7 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
         config.set("browsers", "query_text", text)
 
     def __new_playlist(self, activator, library):
-        playlist = FileBackedPlaylist.new(PLAYLISTS, library=library)
+        playlist = XSPFBackedPlaylist.new(PLAYLISTS, library=library)
         self.model.append(row=[playlist])
         self._select_playlist(playlist, scroll=True)
 
@@ -647,7 +664,7 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
             playlist = model[iter][0]
             playlist[:] = songs
         elif songs:
-            playlist = FileBackedPlaylist.from_songs(PLAYLISTS, songs,
+            playlist = XSPFBackedPlaylist.from_songs(PLAYLISTS, songs,
                                                      self.library)
             GLib.idle_add(self._select_playlist, playlist)
         if playlist:
@@ -660,7 +677,7 @@ class PlaylistsBrowser(Browser, DisplayPatternMixin):
 
 class PreferencesButton(Gtk.HBox):
     def __init__(self, browser):
-        super(PreferencesButton, self).__init__()
+        super().__init__()
 
         menu = Gtk.Menu()
 
