@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2016 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
@@ -34,7 +33,6 @@ class ArtworkUrlCover(CoverSourcePlugin, HTTPDownloadMixin):
         url = self.url
         if url:
             return path.join(cover_dir, escape_filename(url))
-        return super(ArtworkUrlCover, self).cover_path
 
     @property
     def url(self):
