@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2005 Eduardo Gonzalez <wm.eddie@gmail.com>, Niklas Janlert
 #           2006 Joe Wreschnig
 #           2008 Antonio Riva, Eduardo Gonzalez <wm.eddie@gmail.com>,
@@ -58,8 +57,10 @@ REQUEST_LIMIT_MAX = 15
 
 def get_encoding_from_socket(socket):
     content_type = socket.headers.get("Content-Type", "")
-    p = map(str.strip, map(str.lower, content_type.split(";")))
-    enc = [t.split("=")[-1].strip() for t in p if t.startswith("charset")]
+    p = [s.lower().strip()
+         for s in content_type.split(";")]
+    enc = [t.split("=")[-1].strip()
+           for t in p if t.startswith("charset")]
     return (enc and enc[0]) or "utf-8"
 
 
@@ -103,7 +104,7 @@ def get_encoding(url):
     return get_encoding_from_socket(url_sock)
 
 
-class AmazonParser(object):
+class AmazonParser:
     """A class for searching covers from Amazon"""
 
     def __init__(self):
@@ -213,7 +214,7 @@ class AmazonParser(object):
         return self.covers
 
 
-class DiscogsParser(object):
+class DiscogsParser:
     """A class for searching covers from Amazon"""
 
     def __init__(self):
@@ -311,7 +312,7 @@ class CoverArea(Gtk.VBox, PluginConfigMixin):
     CONFIG_SECTION = PLUGIN_CONFIG_SECTION
 
     def __init__(self, parent, song):
-        super(CoverArea, self).__init__()
+        super().__init__()
         self.song = song
 
         self.dirname = song("~dirname")
@@ -384,9 +385,9 @@ class CoverArea(Gtk.VBox, PluginConfigMixin):
         set_fn = self.config_get('filename', fn_list[0])
 
         for i, fn in enumerate(fn_list):
-                self.name_combo.append_text(fn)
-                if fn == set_fn:
-                    self.name_combo.set_active(i)
+            self.name_combo.append_text(fn)
+            if fn == set_fn:
+                self.name_combo.set_active(i)
 
         if self.name_combo.get_active() < 0:
             self.name_combo.set_active(0)
@@ -568,7 +569,7 @@ class CoverArea(Gtk.VBox, PluginConfigMixin):
                 while not self.stop_loading:
                     tmp = url_sock.read(1024 * 10)
                     if not tmp:
-                            break
+                        break
                     pbloader.write(tmp)
                     data_store.write(tmp)
 
@@ -614,7 +615,7 @@ class AlbumArtWindow(qltk.Window, PluginConfigMixin):
     THUMB_SIZE = 50
 
     def __init__(self, songs):
-        super(AlbumArtWindow, self).__init__()
+        super().__init__()
 
         self.image_cache = []
         self.image_cache_size = 10
@@ -888,7 +889,7 @@ class AlbumArtWindow(qltk.Window, PluginConfigMixin):
             self.search_lock = False
 
 
-class CoverSearch(object):
+class CoverSearch:
     """Class for glueing the search engines together. No UI stuff."""
 
     def __init__(self, callback):
@@ -938,8 +939,8 @@ class CoverSearch(object):
         result = []
         try:
             result = engine().start(search, limit)
-        except Exception:
-            print_w("[AlbumArt] %s: %r" % (engine.__name__, query))
+        except Exception as e:
+            print_w(f"[AlbumArt] {engine.__name__}: {query!r} ({e})")
             print_exc()
 
         self.finished += 1
