@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #    ReplayGain Album Analysis using gstreamer rganalysis element
 #    Copyright (C) 2005,2007,2009  Michael Urman
 #                  2012,2014,2016  Nick Boultbee
@@ -26,6 +25,7 @@ from quodlibet.qltk import Icons, Dialog
 from quodlibet.plugins.songsmenu import SongsMenuPlugin
 from quodlibet.plugins.songshelpers import is_writable, is_finite, each_song
 from quodlibet.util import cached_property, print_w, print_e, format_int_locale
+from quodlibet.util.path import uri2gsturi
 
 __all__ = ['ReplayGain']
 
@@ -42,14 +42,14 @@ def get_num_threads():
     return threads
 
 
-class UpdateMode(object):
+class UpdateMode:
     """Enum-like class for update strategies"""
     ALWAYS = "always"
     ALBUM_MISSING = "album_tags_missing"
     ANY_MISSING = "any_tags_missing"
 
 
-class RGAlbum(object):
+class RGAlbum:
     def __init__(self, rg_songs, process_mode):
         self.songs = rg_songs
         self.gain = None
@@ -121,7 +121,7 @@ class RGAlbum(object):
             return True
 
 
-class RGSong(object):
+class RGSong:
     def __init__(self, song):
         self.song = song
         self.error = False
@@ -225,7 +225,7 @@ class ReplayGainPipeline(GObject.Object):
     }
 
     def __init__(self):
-        super(ReplayGainPipeline, self).__init__()
+        super().__init__()
 
         self._current = None
         self._setup_pipe()
@@ -309,7 +309,7 @@ class ReplayGainPipeline(GObject.Object):
             self.pipe.set_state(Gst.State.NULL)
 
         self._current = self._songs.pop(0)
-        self.decode.set_property("uri", self._current.uri)
+        self.decode.set_property("uri", uri2gsturi(self._current.uri))
         if not first:
             # flush, so the element takes new data after EOS
             pad = self.analysis.get_static_pad("src")
@@ -348,7 +348,7 @@ class ReplayGainPipeline(GObject.Object):
 class RGDialog(Dialog):
 
     def __init__(self, albums, parent, process_mode):
-        super(RGDialog, self).__init__(
+        super().__init__(
             title=_('ReplayGain Analyzer'), parent=parent)
 
         self.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
