@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2016 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
@@ -63,10 +62,7 @@ def init():
     MinVersions.MUTAGEN.check(mutagen.version)
 
     base = util.get_module_dir()
-    load_pyc = util.is_windows() or util.is_osx()
-    formats = load_dir_modules(base,
-                               package=__package__,
-                               load_compiled=load_pyc)
+    formats = load_dir_modules(base, package=__package__)
 
     module_names = []
     for format in formats:
