@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2004-2005 Joe Wreschnig, Michael Urman, Iñigo Serna
 #
 # This program is free software; you can redistribute it and/or modify
@@ -32,7 +31,7 @@ from quodlibet.qltk import Icons
 from quodlibet.util.tagsfrompath import TagsFromPattern
 from quodlibet.util.string.splitters import split_value
 from quodlibet.util import connect_obj
-from quodlibet.compat import itervalues
+from quodlibet.plugins.editing import TagsFromPathPlugin
 
 
 TBP = os.path.join(quodlibet.get_user_dir(), "lists", "tagpatterns")
@@ -77,11 +76,10 @@ class SplitTag(FilterCheckButton):
 
 
 class TagsFromPathPluginHandler(EditingPluginHandler):
-    from quodlibet.plugins.editing import TagsFromPathPlugin
     Kind = TagsFromPathPlugin
 
 
-class ListEntry(object):
+class ListEntry:
 
     def __init__(self, song):
         self.song = song
@@ -108,7 +106,7 @@ class TagsFromPath(Gtk.VBox):
         PluginManager.instance.register_handler(cls.handler)
 
     def __init__(self, parent, library):
-        super(TagsFromPath, self).__init__(spacing=6)
+        super().__init__(spacing=6)
 
         self.set_border_width(12)
         hbox = Gtk.HBox(spacing=6)
@@ -282,7 +280,7 @@ class TagsFromPath(Gtk.VBox):
         was_changed = set()
 
         all_done = False
-        for entry in ((model and itervalues(model)) or []):
+        for entry in ((model and model.values()) or []):
             song = entry.song
             changed = False
             if not song.valid():
